import React, { useState, useEffect } from 'react';
import { Modal } from 'src/components';
import ReactMarkdown from 'react-markdown';
import remarkGfm from 'remark-gfm';
import matter from 'gray-matter';
import { QuestionMarkCircleIcon } from '@heroicons/react/outline';

type DashboardCardProps = {
  app: any;
  version: string | number;
};

export const DashboardCard = ({ app, version }: DashboardCardProps) => {
  // export const DashboardCard: React.FC<{ any, string }> = ({ app }: { app: any }, { version }: { version: string }) => {
  const [readMoreVisible, setReadMoreVisible] = useState(false);
  const [rawMarkdown, setContent] = useState('');

  const onReadMoreToggleClick = () => setReadMoreVisible((current) => !current);

  useEffect(() => {
    fetch(app.markdownSrc)
      .then((res) => res.text())
      .then((md) => {
        return setContent(md);
      })
      .catch(() => {});
  }, [app.markdownSrc]);

  const appDescription = matter(rawMarkdown);

  return (
    <>
      <div
        className="bg-white overflow-hidden shadow rounded-lg divide-y divide-gray-100 mb-4 md:mb-0 flex flex-col justify-between relative"
        key={app.name}
      >
        <div className="flex items-end justify-end absolute top-2 right-2">
          <a href="#" onClick={onReadMoreToggleClick} className="flex items-center justify-center">
            <QuestionMarkCircleIcon className="h-4 w-4 text-primary-600 hover:text-primary-800" />
          </a>
        </div>
        <div className="px-4 py-5 sm:p-6">
          <div className="mr-4 flex items-center">
            <img
              className="h-16 w-16 rounded-md overflow-hidden mr-4 flex-shrink-0"
              src={app.assetSrc}
              alt={app.name}
            />

            <div className="flex justify-between gap-1 items-center">
              <h2 className="text-xl leading-8 font-bold">{app.name}</h2>
              <p className="text-xs text-gray-400">{version}</p>
            </div>
          </div>
          <p className="text-gray-500 mt-2 text-sm leading-5 font-normal">{appDescription.data.tileExcerpt}</p>
        </div>
        <div className="px-2.5 py-2.5 sm:px-4 flex justify-end">
          <a
            href={app.slug === 'wordpresss' ? `${app.url}/wp-admin/` : app.url}
            target="_blank"
            rel="noreferrer"
            className="inline-flex items-center px-2.5 py-1.5 border border-transparent shadow-sm text-sm font-medium rounded-md text-white bg-primary-600 hover:bg-primary-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-primary-500"
          >
            Launch App
          </a>
        </div>
      </div>

      <Modal open={readMoreVisible} onClose={onReadMoreToggleClick} title={app.name}>
        <ReactMarkdown
          className="prose prose-slate"
          remarkPlugins={[remarkGfm]}
          components={{
            img: ({ node, ...props }) => <img alt="" width={250} {...props} />,
          }}
        >
          {appDescription.content}
        </ReactMarkdown>
      </Modal>
    </>
  );
};
